@@ -53,7 +53,7 @@ if __name__ == '__main__':
 
     import os
     import json
-    path = os.path.abspath(r'D:\WorkSpace\TruePad\src\TruePad\cfg\TruePad.dat')
+    path = os.path.abspath(sys.argv[1])
 
     with open(path, 'r') as f:
         d = json.load(f)
